# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/unit_format.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/unit_format.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/monitoring/v3/unit_format.proto\x12\x1ayandex.cloud.monitoring.v3*\xa0\x11\n\nUnitFormat\x12\x1b\n\x17UNIT_FORMAT_UNSPECIFIED\x10\x00\x12\r\n\tUNIT_NONE\x10\x01\x12\x0e\n\nUNIT_COUNT\x10\x02\x12\x10\n\x0cUNIT_PERCENT\x10\x03\x12\x15\n\x11UNIT_PERCENT_UNIT\x10\x04\x12\x14\n\x10UNIT_NANOSECONDS\x10\x05\x12\x15\n\x11UNIT_MICROSECONDS\x10\x06\x12\x15\n\x11UNIT_MILLISECONDS\x10\x07\x12\x10\n\x0cUNIT_SECONDS\x10\x08\x12\x10\n\x0cUNIT_MINUTES\x10\t\x12\x0e\n\nUNIT_HOURS\x10\n\x12\r\n\tUNIT_DAYS\x10\x0b\x12\x10\n\x0cUNIT_BITS_SI\x10\x0c\x12\x11\n\rUNIT_BYTES_SI\x10\r\x12\x12\n\x0eUNIT_KILOBYTES\x10\x0e\x12\x12\n\x0eUNIT_MEGABYTES\x10\x0f\x12\x12\n\x0eUNIT_GIGABYTES\x10\x10\x12\x12\n\x0eUNIT_TERABYTES\x10\x11\x12\x12\n\x0eUNIT_PETABYTES\x10\x12\x12\x11\n\rUNIT_EXABYTES\x10\x13\x12\x11\n\rUNIT_BITS_IEC\x10\x14\x12\x12\n\x0eUNIT_BYTES_IEC\x10\x15\x12\x12\n\x0eUNIT_KIBIBYTES\x10\x16\x12\x12\n\x0eUNIT_MEBIBYTES\x10\x17\x12\x12\n\x0eUNIT_GIBIBYTES\x10\x18\x12\x12\n\x0eUNIT_TEBIBYTES\x10\x19\x12\x12\n\x0eUNIT_PEBIBYTES\x10\x1a\x12\x12\n\x0eUNIT_EXBIBYTES\x10\x1b\x12\x1c\n\x18UNIT_REQUESTS_PER_SECOND\x10\x1c\x12\x1e\n\x1aUNIT_OPERATIONS_PER_SECOND\x10\x1d\x12\x1a\n\x16UNIT_WRITES_PER_SECOND\x10\x1e\x12\x19\n\x15UNIT_READS_PER_SECOND\x10\x1f\x12\x1b\n\x17UNIT_PACKETS_PER_SECOND\x10 \x12!\n\x1dUNIT_IO_OPERATIONS_PER_SECOND\x10!\x12\x1a\n\x16UNIT_COUNTS_PER_SECOND\x10\"\x12\x1b\n\x17UNIT_BITS_SI_PER_SECOND\x10#\x12\x1c\n\x18UNIT_BYTES_SI_PER_SECOND\x10$\x12\x1c\n\x18UNIT_KILOBITS_PER_SECOND\x10%\x12\x1d\n\x19UNIT_KILOBYTES_PER_SECOND\x10&\x12\x1c\n\x18UNIT_MEGABITS_PER_SECOND\x10\'\x12\x1d\n\x19UNIT_MEGABYTES_PER_SECOND\x10(\x12\x1c\n\x18UNIT_GIGABITS_PER_SECOND\x10)\x12\x1d\n\x19UNIT_GIGABYTES_PER_SECOND\x10*\x12\x1c\n\x18UNIT_TERABITS_PER_SECOND\x10+\x12\x1d\n\x19UNIT_TERABYTES_PER_SECOND\x10,\x12\x1c\n\x18UNIT_PETABITS_PER_SECOND\x10-\x12\x1d\n\x19UNIT_PETABYTES_PER_SECOND\x10.\x12\x1c\n\x18UNIT_BITS_IEC_PER_SECOND\x10/\x12\x1d\n\x19UNIT_BYTES_IEC_PER_SECOND\x10\x30\x12\x1c\n\x18UNIT_KIBIBITS_PER_SECOND\x10\x31\x12\x1d\n\x19UNIT_KIBIBYTES_PER_SECOND\x10\x32\x12\x1c\n\x18UNIT_MEBIBITS_PER_SECOND\x10\x33\x12\x1d\n\x19UNIT_MEBIBYTES_PER_SECOND\x10\x34\x12\x1c\n\x18UNIT_GIBIBITS_PER_SECOND\x10\x35\x12\x1d\n\x19UNIT_GIBIBYTES_PER_SECOND\x10\x36\x12\x1c\n\x18UNIT_TEBIBITS_PER_SECOND\x10\x37\x12\x1d\n\x19UNIT_TEBIBYTES_PER_SECOND\x10\x38\x12\x1c\n\x18UNIT_PEBIBITS_PER_SECOND\x10\x39\x12\x1d\n\x19UNIT_PEBIBYTES_PER_SECOND\x10:\x12\x15\n\x11UNIT_DATETIME_UTC\x10;\x12\x17\n\x13UNIT_DATETIME_LOCAL\x10<\x12\x0e\n\nUNIT_HERTZ\x10=\x12\x12\n\x0eUNIT_KILOHERTZ\x10>\x12\x12\n\x0eUNIT_MEGAHERTZ\x10?\x12\x12\n\x0eUNIT_GIGAHERTZ\x10@\x12\x0f\n\x0bUNIT_DOLLAR\x10\x41\x12\r\n\tUNIT_EURO\x10\x42\x12\x0f\n\x0bUNIT_ROUBLE\x10\x43\x12\x10\n\x0cUNIT_CELSIUS\x10\x44\x12\x13\n\x0fUNIT_FAHRENHEIT\x10\x45\x12\x0f\n\x0bUNIT_KELVIN\x10\x46\x12\x18\n\x14UNIT_FLOP_PER_SECOND\x10G\x12\x1c\n\x18UNIT_KILOFLOP_PER_SECOND\x10H\x12\x1c\n\x18UNIT_MEGAFLOP_PER_SECOND\x10I\x12\x1c\n\x18UNIT_GIGAFLOP_PER_SECOND\x10J\x12\x1c\n\x18UNIT_PETAFLOP_PER_SECOND\x10K\x12\x1b\n\x17UNIT_EXAFLOP_PER_SECOND\x10L\x12\x1a\n\x16UNIT_METERS_PER_SECOND\x10M\x12\x1c\n\x18UNIT_KILOMETERS_PER_HOUR\x10N\x12\x17\n\x13UNIT_MILES_PER_HOUR\x10O\x12\x13\n\x0fUNIT_MILLIMETER\x10P\x12\x13\n\x0fUNIT_CENTIMETER\x10Q\x12\x0e\n\nUNIT_METER\x10R\x12\x12\n\x0eUNIT_KILOMETER\x10S\x12\r\n\tUNIT_MILE\x10T\x12\x0c\n\x08UNIT_PPM\x10U\x12\x1a\n\x16UNIT_EVENTS_PER_SECOND\x10V\x12\x10\n\x0cUNIT_PACKETS\x10W\x12\x0c\n\x08UNIT_DBM\x10X\x12\x14\n\x10UNIT_VIRTUAL_CPU\x10Y\x12\x1c\n\x18UNIT_MESSAGES_PER_SECOND\x10ZBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.unit_format_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_UNITFORMAT']._serialized_start=77
  _globals['_UNITFORMAT']._serialized_end=2285
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.reference.reference_pb2
import yandex.cloud.vpc.v1.subnet_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource to return.
    To get the subnet ID use a [SubnetService.List] request.
    """
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___GetSubnetRequest = GetSubnetRequest

@typing.final
class ListSubnetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list subnets in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListSubnetsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSubnetsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Subnet.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSubnetsRequest = ListSubnetsRequest

@typing.final
class ListSubnetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSubnetsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListSubnetsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.vpc.v1.subnet_pb2.Subnet]:
        """List of Subnet resources."""

    def __init__(
        self,
        *,
        subnets: collections.abc.Iterable[yandex.cloud.vpc.v1.subnet_pb2.Subnet] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subnets", b"subnets"]) -> None: ...

global___ListSubnetsResponse = ListSubnetsResponse

@typing.final
class CreateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a subnet in.
    To get folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the subnet.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the subnet."""
    network_id: builtins.str
    """ID of the network to create subnet in."""
    zone_id: builtins.str
    """ID of the availability zone where the subnet resides.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    route_table_id: builtins.str
    """IPv6 not available yet.
     repeated string v6_cidr_blocks = 8;

    ID of route table the subnet is linked to.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `` key:value `` pairs."""

    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """CIDR block.
        The range of internal addresses that are defined for this subnet.
        For example, 10.0.0.0/22 or 192.168.0.0/24.
        Minimum subnet size is /28, maximum subnet size is /16.
        """

    @property
    def dhcp_options(self) -> yandex.cloud.vpc.v1.subnet_pb2.DhcpOptions: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        route_table_id: builtins.str = ...,
        dhcp_options: yandex.cloud.vpc.v1.subnet_pb2.DhcpOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "dhcp_options", b"dhcp_options", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "route_table_id", b"route_table_id", "v4_cidr_blocks", b"v4_cidr_blocks", "zone_id", b"zone_id"]) -> None: ...

global___CreateSubnetRequest = CreateSubnetRequest

@typing.final
class CreateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the subnet that is being created."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___CreateSubnetMetadata = CreateSubnetMetadata

@typing.final
class UpdateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SUBNET_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource to update."""
    name: builtins.str
    """Name of the subnet.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the subnet."""
    route_table_id: builtins.str
    """ID of route table the subnet is linked to."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Subnet resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def dhcp_options(self) -> yandex.cloud.vpc.v1.subnet_pb2.DhcpOptions: ...
    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """New CIDR blocks which will overwrite the existing ones."""

    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        route_table_id: builtins.str = ...,
        dhcp_options: yandex.cloud.vpc.v1.subnet_pb2.DhcpOptions | None = ...,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dhcp_options", b"dhcp_options", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "dhcp_options", b"dhcp_options", "labels", b"labels", "name", b"name", "route_table_id", b"route_table_id", "subnet_id", b"subnet_id", "update_mask", b"update_mask", "v4_cidr_blocks", b"v4_cidr_blocks"]) -> None: ...

global___UpdateSubnetRequest = UpdateSubnetRequest

@typing.final
class UpdateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being updated."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___UpdateSubnetMetadata = UpdateSubnetMetadata

@typing.final
class AddSubnetCidrBlocksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being updated."""
    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """CIDR block.
        The range of internal addresses that should be added to this subnet.
        For example, 10.0.0.0/22 or 192.168.0.0/24.
        Minimum subnet size is /28, maximum subnet size is /16.
        """

    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id", "v4_cidr_blocks", b"v4_cidr_blocks"]) -> None: ...

global___AddSubnetCidrBlocksRequest = AddSubnetCidrBlocksRequest

@typing.final
class AddSubnetCidrBlocksMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being updated."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___AddSubnetCidrBlocksMetadata = AddSubnetCidrBlocksMetadata

@typing.final
class RemoveSubnetCidrBlocksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being updated."""
    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """CIDR block.
        The range of internal addresses that are removed from this subnet.
        """

    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id", "v4_cidr_blocks", b"v4_cidr_blocks"]) -> None: ...

global___RemoveSubnetCidrBlocksRequest = RemoveSubnetCidrBlocksRequest

@typing.final
class RemoveSubnetCidrBlocksMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being updated."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___RemoveSubnetCidrBlocksMetadata = RemoveSubnetCidrBlocksMetadata

@typing.final
class DeleteSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the subnet to delete.
    To get the subnet ID use a [SubnetService.List] request.
    """
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___DeleteSubnetRequest = DeleteSubnetRequest

@typing.final
class DeleteSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being deleted."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___DeleteSubnetMetadata = DeleteSubnetMetadata

@typing.final
class ListSubnetOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListSubnetOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSubnetOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "subnet_id", b"subnet_id"]) -> None: ...

global___ListSubnetOperationsRequest = ListSubnetOperationsRequest

@typing.final
class ListSubnetOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSubnetOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListSubnetOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Subnet resource."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSubnetOperationsResponse = ListSubnetOperationsResponse

@typing.final
class MoveSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource to move."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "subnet_id", b"subnet_id"]) -> None: ...

global___MoveSubnetRequest = MoveSubnetRequest

@typing.final
class MoveSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the Subnet resource that is being moved."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___MoveSubnetMetadata = MoveSubnetMetadata

@typing.final
class ListUsedAddressesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    filter: builtins.str
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "subnet_id", b"subnet_id"]) -> None: ...

global___ListUsedAddressesRequest = ListUsedAddressesRequest

@typing.final
class ListUsedAddressesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESSES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsedAddress]: ...
    def __init__(
        self,
        *,
        addresses: collections.abc.Iterable[global___UsedAddress] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["addresses", b"addresses", "next_page_token", b"next_page_token"]) -> None: ...

global___ListUsedAddressesResponse = ListUsedAddressesResponse

@typing.final
class UsedAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    REFERENCES_FIELD_NUMBER: builtins.int
    address: builtins.str
    ip_version: yandex.cloud.vpc.v1.subnet_pb2.IpVersion.ValueType
    @property
    def references(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.reference.reference_pb2.Reference]: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        ip_version: yandex.cloud.vpc.v1.subnet_pb2.IpVersion.ValueType = ...,
        references: collections.abc.Iterable[yandex.cloud.reference.reference_pb2.Reference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "ip_version", b"ip_version", "references", b"references"]) -> None: ...

global___UsedAddress = UsedAddress

@typing.final
class RelocateSubnetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    DESTINATION_ZONE_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    destination_zone_id: builtins.str
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        destination_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_zone_id", b"destination_zone_id", "subnet_id", b"subnet_id"]) -> None: ...

global___RelocateSubnetRequest = RelocateSubnetRequest

@typing.final
class RelocateSubnetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___RelocateSubnetMetadata = RelocateSubnetMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/functions/v1/network_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/functions/v1/network_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/serverless/functions/v1/network_service.proto\x12$yandex.cloud.serverless.functions.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb0\x02\n\x0bUsedNetwork\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12H\n\x06status\x18\x04 \x01(\x0e\x32\x38.yandex.cloud.serverless.functions.v1.UsedNetwork.Status\x12\x39\n\x15will_be_cleaned_up_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11\x63onnections_count\x18\x06 \x01(\x03\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08OBSOLETE\x10\x03\"1\n\x15GetUsedNetworkRequest\x12\x18\n\nnetwork_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8f\x01\n\x17ListUsedNetworksRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x12\n\x08\x63loud_id\x18\x03 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x04 \x01(\tH\x00\x42\r\n\x05scope\x12\x04\xc0\xc1\x31\x01\"x\n\x18ListUsedNetworksResponse\x12\x43\n\x08networks\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.serverless.functions.v1.UsedNetwork\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb3\x01\n\x1dListConnectedResourcesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x14\n\nnetwork_id\x18\x03 \x01(\tH\x00\x12\x12\n\x08\x63loud_id\x18\x04 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x05 \x01(\tH\x00\x42\x15\n\rnetwork_scope\x12\x04\xc0\xc1\x31\x01\"\xe3\x02\n\x1eListConnectedResourcesResponse\x12i\n\tresources\x18\x01 \x03(\x0b\x32V.yandex.cloud.serverless.functions.v1.ListConnectedResourcesResponse.ConnectedResource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbc\x01\n\x11\x43onnectedResource\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x18\n\x10subresource_type\x18\x04 \x01(\t\x12\x16\n\x0esubresource_id\x18\x05 \x01(\t\x12\x19\n\x11resource_cloud_id\x18\x06 \x01(\t\x12\x1a\n\x12resource_folder_id\x18\x07 \x01(\t\"<\n TriggerUsedNetworkCleanupRequest\x12\x18\n\nnetwork_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"]\n!TriggerUsedNetworkCleanupResponse\x12\x38\n\x14network_cleanup_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xad\x06\n\x0eNetworkService\x12\xab\x01\n\x07GetUsed\x12;.yandex.cloud.serverless.functions.v1.GetUsedNetworkRequest\x1a\x31.yandex.cloud.serverless.functions.v1.UsedNetwork\"0\x82\xd3\xe4\x93\x02*\x12(/functions/v1/networks/used/{network_id}\x12\xae\x01\n\x08ListUsed\x12=.yandex.cloud.serverless.functions.v1.ListUsedNetworksRequest\x1a>.yandex.cloud.serverless.functions.v1.ListUsedNetworksResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/functions/v1/networks/used\x12\xcf\x01\n\x16ListConnectedResources\x12\x43.yandex.cloud.serverless.functions.v1.ListConnectedResourcesRequest\x1a\x44.yandex.cloud.serverless.functions.v1.ListConnectedResourcesResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/functions/v1/networks/connections\x12\xe9\x01\n\x12TriggerUsedCleanup\x12\x46.yandex.cloud.serverless.functions.v1.TriggerUsedNetworkCleanupRequest\x1aG.yandex.cloud.serverless.functions.v1.TriggerUsedNetworkCleanupResponse\"B\x82\xd3\xe4\x93\x02<\"7/functions/v1/networks/used/{network_id}:triggerCleanup:\x01*B~\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.functions.v1.network_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functions'
  _globals['_GETUSEDNETWORKREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_GETUSEDNETWORKREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTUSEDNETWORKSREQUEST'].oneofs_by_name['scope']._loaded_options = None
  _globals['_LISTUSEDNETWORKSREQUEST'].oneofs_by_name['scope']._serialized_options = b'\300\3011\001'
  _globals['_LISTUSEDNETWORKSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSEDNETWORKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTUSEDNETWORKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSEDNETWORKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].oneofs_by_name['network_scope']._loaded_options = None
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].oneofs_by_name['network_scope']._serialized_options = b'\300\3011\001'
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCONNECTEDRESOURCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _globals['_NETWORKSERVICE'].methods_by_name['GetUsed']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['GetUsed']._serialized_options = b'\202\323\344\223\002*\022(/functions/v1/networks/used/{network_id}'
  _globals['_NETWORKSERVICE'].methods_by_name['ListUsed']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListUsed']._serialized_options = b'\202\323\344\223\002\035\022\033/functions/v1/networks/used'
  _globals['_NETWORKSERVICE'].methods_by_name['ListConnectedResources']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListConnectedResources']._serialized_options = b'\202\323\344\223\002$\022\"/functions/v1/networks/connections'
  _globals['_NETWORKSERVICE'].methods_by_name['TriggerUsedCleanup']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['TriggerUsedCleanup']._serialized_options = b'\202\323\344\223\002<\"7/functions/v1/networks/used/{network_id}:triggerCleanup:\001*'
  _globals['_USEDNETWORK']._serialized_start=195
  _globals['_USEDNETWORK']._serialized_end=499
  _globals['_USEDNETWORK_STATUS']._serialized_start=427
  _globals['_USEDNETWORK_STATUS']._serialized_end=499
  _globals['_GETUSEDNETWORKREQUEST']._serialized_start=501
  _globals['_GETUSEDNETWORKREQUEST']._serialized_end=550
  _globals['_LISTUSEDNETWORKSREQUEST']._serialized_start=553
  _globals['_LISTUSEDNETWORKSREQUEST']._serialized_end=696
  _globals['_LISTUSEDNETWORKSRESPONSE']._serialized_start=698
  _globals['_LISTUSEDNETWORKSRESPONSE']._serialized_end=818
  _globals['_LISTCONNECTEDRESOURCESREQUEST']._serialized_start=821
  _globals['_LISTCONNECTEDRESOURCESREQUEST']._serialized_end=1000
  _globals['_LISTCONNECTEDRESOURCESRESPONSE']._serialized_start=1003
  _globals['_LISTCONNECTEDRESOURCESRESPONSE']._serialized_end=1358
  _globals['_LISTCONNECTEDRESOURCESRESPONSE_CONNECTEDRESOURCE']._serialized_start=1170
  _globals['_LISTCONNECTEDRESOURCESRESPONSE_CONNECTEDRESOURCE']._serialized_end=1358
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST']._serialized_start=1360
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST']._serialized_end=1420
  _globals['_TRIGGERUSEDNETWORKCLEANUPRESPONSE']._serialized_start=1422
  _globals['_TRIGGERUSEDNETWORKCLEANUPRESPONSE']._serialized_end=1515
  _globals['_NETWORKSERVICE']._serialized_start=1518
  _globals['_NETWORKSERVICE']._serialized_end=2331
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TuningTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TuningTask._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: TuningTask._Status.ValueType  # 0
        CREATED: TuningTask._Status.ValueType  # 1
        PENDING: TuningTask._Status.ValueType  # 2
        IN_PROGRESS: TuningTask._Status.ValueType  # 3
        COMPLETED: TuningTask._Status.ValueType  # 4
        FAILED: TuningTask._Status.ValueType  # 5
        CANCELED: TuningTask._Status.ValueType  # 6

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: TuningTask.Status.ValueType  # 0
    CREATED: TuningTask.Status.ValueType  # 1
    PENDING: TuningTask.Status.ValueType  # 2
    IN_PROGRESS: TuningTask.Status.ValueType  # 3
    COMPLETED: TuningTask.Status.ValueType  # 4
    FAILED: TuningTask.Status.ValueType  # 5
    CANCELED: TuningTask.Status.ValueType  # 6

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_ID_FIELD_NUMBER: builtins.int
    OPERATION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    SOURCE_MODEL_URI_FIELD_NUMBER: builtins.int
    TARGET_MODEL_URI_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    operation_id: builtins.str
    status: global___TuningTask.Status.ValueType
    folder_id: builtins.str
    created_by: builtins.str
    source_model_uri: builtins.str
    target_model_uri: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        operation_id: builtins.str = ...,
        status: global___TuningTask.Status.ValueType = ...,
        folder_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source_model_uri: builtins.str = ...,
        target_model_uri: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "finished_at", b"finished_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "description", b"description", "finished_at", b"finished_at", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "operation_id", b"operation_id", "source_model_uri", b"source_model_uri", "started_at", b"started_at", "status", b"status", "target_model_uri", b"target_model_uri", "task_id", b"task_id"]) -> None: ...

global___TuningTask = TuningTask



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.mdb.elasticsearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2
from yandex.cloud.mdb.elasticsearch.v1 import auth_service_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/mdb/elasticsearch/v1/auth_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AuthServiceStub(object):
    """A set of methods for managing Elasticsearch Authentication resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListProviders = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/ListProviders',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersResponse.FromString,
                _registered_method=True)
        self.GetProvider = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/GetProvider',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.GetAuthProviderRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2.AuthProvider.FromString,
                _registered_method=True)
        self.AddProviders = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/AddProviders',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.AddAuthProvidersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateProviders = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/UpdateProviders',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProvidersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DeleteProviders = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/DeleteProviders',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProvidersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateProvider = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/UpdateProvider',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProviderRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DeleteProvider = channel.unary_unary(
                '/yandex.cloud.mdb.elasticsearch.v1.AuthService/DeleteProvider',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProviderRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class AuthServiceServicer(object):
    """A set of methods for managing Elasticsearch Authentication resources.
    """

    def ListProviders(self, request, context):
        """Retrieves the list of registered auth providers for Elasticsearch cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProvider(self, request, context):
        """Returns registered auth provider by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProviders(self, request, context):
        """Adds new auth providers to Elasticsearch cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProviders(self, request, context):
        """Replase the list of auth providers.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProviders(self, request, context):
        """Removes auth providers from Elasticsearch cluster by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProvider(self, request, context):
        """Updates registered auth provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProvider(self, request, context):
        """Removes auth provider from Elasticsearch cluster by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProviders,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersResponse.SerializeToString,
            ),
            'GetProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProvider,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.GetAuthProviderRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2.AuthProvider.SerializeToString,
            ),
            'AddProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProviders,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.AddAuthProvidersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProviders,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProvidersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProviders,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProvidersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProvider,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProviderRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProvider,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProviderRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.mdb.elasticsearch.v1.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.mdb.elasticsearch.v1.AuthService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """A set of methods for managing Elasticsearch Authentication resources.
    """

    @staticmethod
    def ListProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/ListProviders',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.ListAuthProvidersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/GetProvider',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.GetAuthProviderRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2.AuthProvider.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/AddProviders',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.AddAuthProvidersRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/UpdateProviders',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProvidersRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/DeleteProviders',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProvidersRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/UpdateProvider',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.UpdateAuthProviderRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.elasticsearch.v1.AuthService/DeleteProvider',
            yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__service__pb2.DeleteAuthProviderRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/device_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/device_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iot.devices.v1 import device_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/iot/devices/v1/device_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/iot/devices/v1/device.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"q\n\x10GetDeviceRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0b\x64\x65vice_view\x18\x02 \x01(\x0e\x32\'.yandex.cloud.iot.devices.v1.DeviceView\"\xae\x01\n\x16GetByNameDeviceRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12<\n\x0b\x64\x65vice_view\x18\x03 \x01(\x0e\x32\'.yandex.cloud.iot.devices.v1.DeviceView\"\xdd\x01\n\x12ListDevicesRequest\x12\x1f\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1e\n\tpage_size\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-20000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12<\n\x0b\x64\x65vice_view\x18\x05 \x01(\x0e\x32\'.yandex.cloud.iot.devices.v1.DeviceViewB\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"d\n\x13ListDevicesResponse\x12\x34\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32#.yandex.cloud.iot.devices.v1.Device\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe0\x04\n\x13\x43reateDeviceRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12R\n\x0c\x63\x65rtificates\x18\x04 \x03(\x0b\x32<.yandex.cloud.iot.devices.v1.CreateDeviceRequest.Certificate\x12Y\n\rtopic_aliases\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.iot.devices.v1.CreateDeviceRequest.TopicAliasesEntry\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x89\x01\n\x06labels\x18\x07 \x03(\x0b\x32<.yandex.cloud.iot.devices.v1.CreateDeviceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a\x33\n\x11TopicAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\'\n\x0b\x43\x65rtificate\x12\x18\n\x10\x63\x65rtificate_data\x18\x01 \x01(\t\")\n\x14\x43reateDeviceMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"\xfc\x03\n\x13UpdateDeviceRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12Y\n\rtopic_aliases\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.iot.devices.v1.UpdateDeviceRequest.TopicAliasesEntry\x12\x89\x01\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.iot.devices.v1.UpdateDeviceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a\x33\n\x11TopicAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateDeviceMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteDeviceRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteDeviceMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\t\"@\n\x1dListDeviceCertificatesRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"f\n\x1eListDeviceCertificatesResponse\x12\x44\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32..yandex.cloud.iot.devices.v1.DeviceCertificate\"^\n\x1b\x41\x64\x64\x44\x65viceCertificateRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"F\n\x1c\x41\x64\x64\x44\x65viceCertificateMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"d\n\x1e\x44\x65leteDeviceCertificateRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1f\x44\x65leteDeviceCertificateMetadata\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1aListDevicePasswordsRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"]\n\x1bListDevicePasswordsResponse\x12>\n\tpasswords\x18\x01 \x03(\x0b\x32+.yandex.cloud.iot.devices.v1.DevicePassword\"W\n\x18\x41\x64\x64\x44\x65vicePasswordRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x08password\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04>=14\"C\n\x19\x41\x64\x64\x44\x65vicePasswordMetadata\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0bpassword_id\x18\x02 \x01(\t\"a\n\x1b\x44\x65leteDevicePasswordRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x1c\x44\x65leteDevicePasswordMetadata\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x1bListDeviceOperationsRequest\x12\x17\n\tdevice_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"n\n\x1cListDeviceOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb0\x13\n\rDeviceService\x12\x86\x01\n\x03Get\x12-.yandex.cloud.iot.devices.v1.GetDeviceRequest\x1a#.yandex.cloud.iot.devices.v1.Device\"+\x82\xd3\xe4\x93\x02%\x12#/iot-devices/v1/devices/{device_id}\x12\x90\x01\n\tGetByName\x12\x33.yandex.cloud.iot.devices.v1.GetByNameDeviceRequest\x1a#.yandex.cloud.iot.devices.v1.Device\")\x82\xd3\xe4\x93\x02#\x12!/iot-devices/v1/devices:getByName\x12\x8a\x01\n\x04List\x12/.yandex.cloud.iot.devices.v1.ListDevicesRequest\x1a\x30.yandex.cloud.iot.devices.v1.ListDevicesResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/iot-devices/v1/devices\x12\xa3\x01\n\x06\x43reate\x12\x30.yandex.cloud.iot.devices.v1.CreateDeviceRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\x1e\n\x14\x43reateDeviceMetadata\x12\x06\x44\x65vice\x82\xd3\xe4\x93\x02\x1c\"\x17/iot-devices/v1/devices:\x01*\x12\xaf\x01\n\x06Update\x12\x30.yandex.cloud.iot.devices.v1.UpdateDeviceRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\x1e\n\x14UpdateDeviceMetadata\x12\x06\x44\x65vice\x82\xd3\xe4\x93\x02(2#/iot-devices/v1/devices/{device_id}:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.iot.devices.v1.DeleteDeviceRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*-\n\x14\x44\x65leteDeviceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/iot-devices/v1/devices/{device_id}\x12\xc5\x01\n\x10ListCertificates\x12:.yandex.cloud.iot.devices.v1.ListDeviceCertificatesRequest\x1a;.yandex.cloud.iot.devices.v1.ListDeviceCertificatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/iot-devices/v1/devices/{device_id}/certificates\x12\xdf\x01\n\x0e\x41\x64\x64\x43\x65rtificate\x12\x38.yandex.cloud.iot.devices.v1.AddDeviceCertificateRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*1\n\x1c\x41\x64\x64\x44\x65viceCertificateMetadata\x12\x11\x44\x65viceCertificate\x82\xd3\xe4\x93\x02\x35\"0/iot-devices/v1/devices/{device_id}/certificates:\x01*\x12\xf8\x01\n\x11\x44\x65leteCertificate\x12;.yandex.cloud.iot.devices.v1.DeleteDeviceCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*8\n\x1f\x44\x65leteDeviceCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/iot-devices/v1/devices/{device_id}/certificates/{fingerprint}\x12\xb9\x01\n\rListPasswords\x12\x37.yandex.cloud.iot.devices.v1.ListDevicePasswordsRequest\x1a\x38.yandex.cloud.iot.devices.v1.ListDevicePasswordsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/iot-devices/v1/devices/{device_id}/passwords\x12\xd0\x01\n\x0b\x41\x64\x64Password\x12\x35.yandex.cloud.iot.devices.v1.AddDevicePasswordRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*+\n\x19\x41\x64\x64\x44\x65vicePasswordMetadata\x12\x0e\x44\x65vicePassword\x82\xd3\xe4\x93\x02\x32\"-/iot-devices/v1/devices/{device_id}/passwords:\x01*\x12\xeb\x01\n\x0e\x44\x65letePassword\x12\x38.yandex.cloud.iot.devices.v1.DeleteDevicePasswordRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*5\n\x1c\x44\x65leteDevicePasswordMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/iot-devices/v1/devices/{device_id}/passwords/{password_id}\x12\xbd\x01\n\x0eListOperations\x12\x38.yandex.cloud.iot.devices.v1.ListDeviceOperationsRequest\x1a\x39.yandex.cloud.iot.devices.v1.ListDeviceOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./iot-devices/v1/devices/{device_id}/operationsBj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.device_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_GETDEVICEREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_GETDEVICEREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETBYNAMEDEVICEREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_GETBYNAMEDEVICEREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETBYNAMEDEVICEREQUEST'].fields_by_name['device_name']._loaded_options = None
  _globals['_GETBYNAMEDEVICEREQUEST'].fields_by_name['device_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_LISTDEVICESREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTDEVICESREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTDEVICESREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTDEVICESREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTDEVICESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDEVICESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTDEVICESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDEVICESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0070-20000'
  _globals['_LISTDEVICESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDEVICESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEDEVICEREQUEST_TOPICALIASESENTRY']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDEVICEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEDEVICEREQUEST_TOPICALIASESENTRY']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDEVICEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEDEVICEREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_DELETEDEVICEREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDEVICECERTIFICATESREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTDEVICECERTIFICATESREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDDEVICECERTIFICATEREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_ADDDEVICECERTIFICATEREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICECERTIFICATEREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_DELETEDEVICECERTIFICATEREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICECERTIFICATEREQUEST'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEDEVICECERTIFICATEREQUEST'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICECERTIFICATEMETADATA'].fields_by_name['device_id']._loaded_options = None
  _globals['_DELETEDEVICECERTIFICATEMETADATA'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICECERTIFICATEMETADATA'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEDEVICECERTIFICATEMETADATA'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDEVICEPASSWORDSREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTDEVICEPASSWORDSREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDDEVICEPASSWORDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_ADDDEVICEPASSWORDREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDDEVICEPASSWORDREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_ADDDEVICEPASSWORDREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\004>=14'
  _globals['_DELETEDEVICEPASSWORDREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_DELETEDEVICEPASSWORDREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICEPASSWORDREQUEST'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEDEVICEPASSWORDREQUEST'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICEPASSWORDMETADATA'].fields_by_name['device_id']._loaded_options = None
  _globals['_DELETEDEVICEPASSWORDMETADATA'].fields_by_name['device_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDEVICEPASSWORDMETADATA'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEDEVICEPASSWORDMETADATA'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['device_id']._loaded_options = None
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['device_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDEVICEOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DEVICESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/iot-devices/v1/devices/{device_id}'
  _globals['_DEVICESERVICE'].methods_by_name['GetByName']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['GetByName']._serialized_options = b'\202\323\344\223\002#\022!/iot-devices/v1/devices:getByName'
  _globals['_DEVICESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/iot-devices/v1/devices'
  _globals['_DEVICESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateDeviceMetadata\022\006Device\202\323\344\223\002\034\"\027/iot-devices/v1/devices:\001*'
  _globals['_DEVICESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateDeviceMetadata\022\006Device\202\323\344\223\002(2#/iot-devices/v1/devices/{device_id}:\001*'
  _globals['_DEVICESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteDeviceMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/iot-devices/v1/devices/{device_id}'
  _globals['_DEVICESERVICE'].methods_by_name['ListCertificates']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['ListCertificates']._serialized_options = b'\202\323\344\223\0022\0220/iot-devices/v1/devices/{device_id}/certificates'
  _globals['_DEVICESERVICE'].methods_by_name['AddCertificate']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['AddCertificate']._serialized_options = b'\262\322*1\n\034AddDeviceCertificateMetadata\022\021DeviceCertificate\202\323\344\223\0025\"0/iot-devices/v1/devices/{device_id}/certificates:\001*'
  _globals['_DEVICESERVICE'].methods_by_name['DeleteCertificate']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['DeleteCertificate']._serialized_options = b'\262\322*8\n\037DeleteDeviceCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/iot-devices/v1/devices/{device_id}/certificates/{fingerprint}'
  _globals['_DEVICESERVICE'].methods_by_name['ListPasswords']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['ListPasswords']._serialized_options = b'\202\323\344\223\002/\022-/iot-devices/v1/devices/{device_id}/passwords'
  _globals['_DEVICESERVICE'].methods_by_name['AddPassword']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['AddPassword']._serialized_options = b'\262\322*+\n\031AddDevicePasswordMetadata\022\016DevicePassword\202\323\344\223\0022\"-/iot-devices/v1/devices/{device_id}/passwords:\001*'
  _globals['_DEVICESERVICE'].methods_by_name['DeletePassword']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['DeletePassword']._serialized_options = b'\262\322*5\n\034DeleteDevicePasswordMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/iot-devices/v1/devices/{device_id}/passwords/{password_id}'
  _globals['_DEVICESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DEVICESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0020\022./iot-devices/v1/devices/{device_id}/operations'
  _globals['_GETDEVICEREQUEST']._serialized_start=292
  _globals['_GETDEVICEREQUEST']._serialized_end=405
  _globals['_GETBYNAMEDEVICEREQUEST']._serialized_start=408
  _globals['_GETBYNAMEDEVICEREQUEST']._serialized_end=582
  _globals['_LISTDEVICESREQUEST']._serialized_start=585
  _globals['_LISTDEVICESREQUEST']._serialized_end=806
  _globals['_LISTDEVICESRESPONSE']._serialized_start=808
  _globals['_LISTDEVICESRESPONSE']._serialized_end=908
  _globals['_CREATEDEVICEREQUEST']._serialized_start=911
  _globals['_CREATEDEVICEREQUEST']._serialized_end=1519
  _globals['_CREATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_start=1380
  _globals['_CREATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_end=1431
  _globals['_CREATEDEVICEREQUEST_LABELSENTRY']._serialized_start=1433
  _globals['_CREATEDEVICEREQUEST_LABELSENTRY']._serialized_end=1478
  _globals['_CREATEDEVICEREQUEST_CERTIFICATE']._serialized_start=1480
  _globals['_CREATEDEVICEREQUEST_CERTIFICATE']._serialized_end=1519
  _globals['_CREATEDEVICEMETADATA']._serialized_start=1521
  _globals['_CREATEDEVICEMETADATA']._serialized_end=1562
  _globals['_UPDATEDEVICEREQUEST']._serialized_start=1565
  _globals['_UPDATEDEVICEREQUEST']._serialized_end=2073
  _globals['_UPDATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_start=1380
  _globals['_UPDATEDEVICEREQUEST_TOPICALIASESENTRY']._serialized_end=1431
  _globals['_UPDATEDEVICEREQUEST_LABELSENTRY']._serialized_start=1433
  _globals['_UPDATEDEVICEREQUEST_LABELSENTRY']._serialized_end=1478
  _globals['_UPDATEDEVICEMETADATA']._serialized_start=2075
  _globals['_UPDATEDEVICEMETADATA']._serialized_end=2116
  _globals['_DELETEDEVICEREQUEST']._serialized_start=2118
  _globals['_DELETEDEVICEREQUEST']._serialized_end=2172
  _globals['_DELETEDEVICEMETADATA']._serialized_start=2174
  _globals['_DELETEDEVICEMETADATA']._serialized_end=2215
  _globals['_LISTDEVICECERTIFICATESREQUEST']._serialized_start=2217
  _globals['_LISTDEVICECERTIFICATESREQUEST']._serialized_end=2281
  _globals['_LISTDEVICECERTIFICATESRESPONSE']._serialized_start=2283
  _globals['_LISTDEVICECERTIFICATESRESPONSE']._serialized_end=2385
  _globals['_ADDDEVICECERTIFICATEREQUEST']._serialized_start=2387
  _globals['_ADDDEVICECERTIFICATEREQUEST']._serialized_end=2481
  _globals['_ADDDEVICECERTIFICATEMETADATA']._serialized_start=2483
  _globals['_ADDDEVICECERTIFICATEMETADATA']._serialized_end=2553
  _globals['_DELETEDEVICECERTIFICATEREQUEST']._serialized_start=2555
  _globals['_DELETEDEVICECERTIFICATEREQUEST']._serialized_end=2655
  _globals['_DELETEDEVICECERTIFICATEMETADATA']._serialized_start=2657
  _globals['_DELETEDEVICECERTIFICATEMETADATA']._serialized_end=2758
  _globals['_LISTDEVICEPASSWORDSREQUEST']._serialized_start=2760
  _globals['_LISTDEVICEPASSWORDSREQUEST']._serialized_end=2821
  _globals['_LISTDEVICEPASSWORDSRESPONSE']._serialized_start=2823
  _globals['_LISTDEVICEPASSWORDSRESPONSE']._serialized_end=2916
  _globals['_ADDDEVICEPASSWORDREQUEST']._serialized_start=2918
  _globals['_ADDDEVICEPASSWORDREQUEST']._serialized_end=3005
  _globals['_ADDDEVICEPASSWORDMETADATA']._serialized_start=3007
  _globals['_ADDDEVICEPASSWORDMETADATA']._serialized_end=3074
  _globals['_DELETEDEVICEPASSWORDREQUEST']._serialized_start=3076
  _globals['_DELETEDEVICEPASSWORDREQUEST']._serialized_end=3173
  _globals['_DELETEDEVICEPASSWORDMETADATA']._serialized_start=3175
  _globals['_DELETEDEVICEPASSWORDMETADATA']._serialized_end=3273
  _globals['_LISTDEVICEOPERATIONSREQUEST']._serialized_start=3276
  _globals['_LISTDEVICEOPERATIONSREQUEST']._serialized_end=3420
  _globals['_LISTDEVICEOPERATIONSRESPONSE']._serialized_start=3422
  _globals['_LISTDEVICEOPERATIONSRESPONSE']._serialized_end=3532
  _globals['_DEVICESERVICE']._serialized_start=3535
  _globals['_DEVICESERVICE']._serialized_end=6015
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.loadtesting.api.v1.report.kpi_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Widget(google.protobuf.message.Message):
    """Regression dashboard widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LayoutPosition(google.protobuf.message.Message):
        """Widget position."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        X_FIELD_NUMBER: builtins.int
        Y_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        x: builtins.int
        """X."""
        y: builtins.int
        """Y."""
        width: builtins.int
        """Width."""
        height: builtins.int
        """Height."""
        def __init__(
            self,
            *,
            x: builtins.int = ...,
            y: builtins.int = ...,
            width: builtins.int = ...,
            height: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["height", b"height", "width", b"width", "x", b"x", "y", b"y"]) -> None: ...

    POSITION_FIELD_NUMBER: builtins.int
    CHART_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> global___Widget.LayoutPosition:
        """Widget position."""

    @property
    def chart(self) -> global___ChartWidget:
        """Chart widget."""

    @property
    def text(self) -> global___TextWidget:
        """Text widget."""

    @property
    def title(self) -> global___TitleWidget:
        """Title widget."""

    def __init__(
        self,
        *,
        position: global___Widget.LayoutPosition | None = ...,
        chart: global___ChartWidget | None = ...,
        text: global___TextWidget | None = ...,
        title: global___TitleWidget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["widget", b"widget"]) -> typing.Literal["chart", "text", "title"] | None: ...

global___Widget = Widget

@typing.final
class ChartWidget(google.protobuf.message.Message):
    """Regression chart."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTER_STR_FIELD_NUMBER: builtins.int
    TEST_CASE_FIELD_NUMBER: builtins.int
    KPIS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the chart."""
    name: builtins.str
    """Name of the chart."""
    description: builtins.str
    """Description of the chart."""
    filter_str: builtins.str
    """Test filter selector to show KPI values for."""
    test_case: builtins.str
    """Test case to show KPI values for."""
    @property
    def kpis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi]:
        """KPIs to show."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        filter_str: builtins.str = ...,
        test_case: builtins.str = ...,
        kpis: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "filter_str", b"filter_str", "id", b"id", "kpis", b"kpis", "name", b"name", "test_case", b"test_case"]) -> None: ...

global___ChartWidget = ChartWidget

@typing.final
class TextWidget(google.protobuf.message.Message):
    """Text widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text string."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

global___TextWidget = TextWidget

@typing.final
class TitleWidget(google.protobuf.message.Message):
    """Title widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TitleSize:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TitleSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleWidget._TitleSize.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TITLE_SIZE_UNSPECIFIED: TitleWidget._TitleSize.ValueType  # 0
        """Unspecified."""
        TITLE_SIZE_XS: TitleWidget._TitleSize.ValueType  # 1
        """Extra small."""
        TITLE_SIZE_S: TitleWidget._TitleSize.ValueType  # 2
        """Small."""
        TITLE_SIZE_M: TitleWidget._TitleSize.ValueType  # 3
        """Medium."""
        TITLE_SIZE_L: TitleWidget._TitleSize.ValueType  # 4
        """Large."""

    class TitleSize(_TitleSize, metaclass=_TitleSizeEnumTypeWrapper):
        """Title size."""

    TITLE_SIZE_UNSPECIFIED: TitleWidget.TitleSize.ValueType  # 0
    """Unspecified."""
    TITLE_SIZE_XS: TitleWidget.TitleSize.ValueType  # 1
    """Extra small."""
    TITLE_SIZE_S: TitleWidget.TitleSize.ValueType  # 2
    """Small."""
    TITLE_SIZE_M: TitleWidget.TitleSize.ValueType  # 3
    """Medium."""
    TITLE_SIZE_L: TitleWidget.TitleSize.ValueType  # 4
    """Large."""

    TEXT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Title string."""
    size: global___TitleWidget.TitleSize.ValueType
    """Title size."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        size: global___TitleWidget.TitleSize.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["size", b"size", "text", b"text"]) -> None: ...

global___TitleWidget = TitleWidget
